//! Start geckodriveror connect to an existing one.

use std::{net::TcpStream, process::Stdio, time::Duration};

use anyhow::Result;
use tokio::{process::Command, spawn, sync::oneshot, task::JoinHandle};

/// Standard address for geckodriver to listen on.
pub const GECKODRIVER_HOST: &str = "127.0.0.1:4444";
const GECKODRIVER_BINARY: &str = "geckodriver";

/// Check if ageckodriver is already running and if not start one.
pub async fn run(stop_rx: oneshot::Receiver<()>) -> Result<Option<JoinHandle<()>>> {
    if TcpStream::connect_timeout(&GECKODRIVER_HOST.parse()?, Duration::from_secs(2)).is_err() {
        let handle = spawn(async move {
            let mut child = Command::new(GECKODRIVER_BINARY)
                .stdout(Stdio::null())
                .spawn()
                .expect("failed to run binary");
            tokio::select! {
                _ = stop_rx => {
                    child.kill().await.expect("Failed to kill process");
                }
                result = child.wait() => {
                    result.expect("Child process wasn't running");
                }
            }
        });
        Ok(Some(handle))
    } else {
        Ok(None)
    }
}
