use std::io::{self, Read};

use anyhow::Result;
use clap::Parser;
use nzz_download::cli::Config;

#[tokio::main]
async fn main() -> Result<()> {
    if std::env::var_os("RUST_LOG").is_none() {
        std::env::set_var("RUST_LOG", "info");
    }

    tracing_subscriber::fmt::init();

    let args = Config::parse();
    let cookie = read_cookie().expect("Provide the authentication cookie via stdin");

    nzz_download::run(args, &cookie).await
}

/// read authentication cookie from stdin.
fn read_cookie() -> Result<String> {
    let stdin = io::stdin();
    let mut buffer = String::new();

    stdin.lock().read_to_string(&mut buffer)?;
    let cookie = buffer.trim();
    Ok(cookie.to_string())
}
